@@ -1,4 +1,4 @@
-// Copyright 2014 PDFium Authors. All rights reserved.
+// Copyright 2014 The PDFium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -13,6 +13,8 @@
 #include "xfa/fgas/graphics/cfgas_gecolor.h"
 #include "xfa/fwl/cfwl_widget.h"
 
+namespace pdfium {
+
 class CFWL_Caret final : public CFWL_Widget, public CFX_Timer::CallbackIface {
  public:
   CONSTRUCT_VIA_MAKE_GARBAGE_COLLECTED;
@@ -36,9 +38,14 @@ class CFWL_Caret final : public CFWL_Widget, public CFX_Timer::CallbackIface {
  private:
   CFWL_Caret(CFWL_App* app, const Properties& properties, CFWL_Widget* pOuter);
 
-  void DrawCaretBK(CFGAS_GEGraphics* pGraphics, const CFX_Matrix* pMatrix);
+  void DrawCaretBK(CFGAS_GEGraphics* pGraphics, const CFX_Matrix& mtMatrix);
 
   std::unique_ptr<CFX_Timer> m_pTimer;
 };
 
+}  // namespace pdfium
+
+// TODO(crbug.com/42271761): Remove.
+using pdfium::CFWL_Caret;
+
 #endif  // XFA_FWL_CFWL_CARET_H_
